/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.4.0 (build: 2013-06-20 19:08:55 UTC)
 *  on 2013-06-24 at 04:39:19 UTC 
 */

package com.google.api.services.taskqueue;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.common.base.Preconditions;

/**
 * Service definition for Taskqueue (v1beta2).
 *
 * <p>
 * Lets you access a Google App Engine Pull Task Queue over REST.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/appengine/docs/python/taskqueue/rest" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link TaskqueueRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Taskqueue extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the TaskQueue API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "taskqueue/v1beta2/projects/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Taskqueue(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  Taskqueue(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Taskqueues collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Taskqueue taskqueue = new Taskqueue(...);}
   *   {@code Taskqueue.Taskqueues.List request = taskqueue.taskqueues().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Taskqueues taskqueues() {
    return new Taskqueues();
  }

  /**
   * The "taskqueues" collection of methods.
   */
  public class Taskqueues {

    /**
     * Get detailed information about a TaskQueue.
     *
     * Create a request for the method "taskqueues.get".
     *
     * This request holds the parameters needed by the the taskqueue server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param project The project under which the queue lies.
     * @param taskqueue The id of the taskqueue to get the properties of.
     * @return the request
     */
    public Get get(String project, String taskqueue) throws java.io.IOException {
      Get result = new Get(project, taskqueue);
      initialize(result);
      return result;
    }

    public class Get extends TaskqueueRequest<com.google.api.services.taskqueue.model.TaskQueue> {

      private static final String REST_PATH = "{project}/taskqueues/{taskqueue}";

      /**
       * Get detailed information about a TaskQueue.
       *
       * Create a request for the method "taskqueues.get".
       *
       * This request holds the parameters needed by the the taskqueue server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param project The project under which the queue lies.
       * @param taskqueue The id of the taskqueue to get the properties of.
       * @since 1.13
       */
      protected Get(String project, String taskqueue) {
        super(Taskqueue.this, "GET", REST_PATH, null, com.google.api.services.taskqueue.model.TaskQueue.class);
        this.project = Preconditions.checkNotNull(project, "Required parameter project must be specified.");
        this.taskqueue = Preconditions.checkNotNull(taskqueue, "Required parameter taskqueue must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The project under which the queue lies. */
      @com.google.api.client.util.Key
      private String project;

      /** The project under which the queue lies.
       */
      public String getProject() {
        return project;
      }

      /** The project under which the queue lies. */
      public Get setProject(String project) {
        this.project = project;
        return this;
      }

      /** The id of the taskqueue to get the properties of. */
      @com.google.api.client.util.Key
      private String taskqueue;

      /** The id of the taskqueue to get the properties of.
       */
      public String getTaskqueue() {
        return taskqueue;
      }

      /** The id of the taskqueue to get the properties of. */
      public Get setTaskqueue(String taskqueue) {
        this.taskqueue = taskqueue;
        return this;
      }

      /** Whether to get stats. Optional. */
      @com.google.api.client.util.Key
      private Boolean getStats;

      /** Whether to get stats. Optional.
       */
      public Boolean getGetStats() {
        return getStats;
      }

      /** Whether to get stats. Optional. */
      public Get setGetStats(Boolean getStats) {
        this.getStats = getStats;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Tasks collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Taskqueue taskqueue = new Taskqueue(...);}
   *   {@code Taskqueue.Tasks.List request = taskqueue.tasks().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Tasks tasks() {
    return new Tasks();
  }

  /**
   * The "tasks" collection of methods.
   */
  public class Tasks {

    /**
     * Delete a task from a TaskQueue.
     *
     * Create a request for the method "tasks.delete".
     *
     * This request holds the parameters needed by the the taskqueue server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param project The project under which the queue lies.
     * @param taskqueue The taskqueue to delete a task from.
     * @param task The id of the task to delete.
     * @return the request
     */
    public Delete delete(String project, String taskqueue, String task) throws java.io.IOException {
      Delete result = new Delete(project, taskqueue, task);
      initialize(result);
      return result;
    }

    public class Delete extends TaskqueueRequest<Void> {

      private static final String REST_PATH = "{project}/taskqueues/{taskqueue}/tasks/{task}";

      /**
       * Delete a task from a TaskQueue.
       *
       * Create a request for the method "tasks.delete".
       *
       * This request holds the parameters needed by the the taskqueue server.  After setting any
       * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       * <p> {@link Delete#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param project The project under which the queue lies.
       * @param taskqueue The taskqueue to delete a task from.
       * @param task The id of the task to delete.
       * @since 1.13
       */
      protected Delete(String project, String taskqueue, String task) {
        super(Taskqueue.this, "DELETE", REST_PATH, null, Void.class);
        this.project = Preconditions.checkNotNull(project, "Required parameter project must be specified.");
        this.taskqueue = Preconditions.checkNotNull(taskqueue, "Required parameter taskqueue must be specified.");
        this.task = Preconditions.checkNotNull(task, "Required parameter task must be specified.");
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      /** The project under which the queue lies. */
      @com.google.api.client.util.Key
      private String project;

      /** The project under which the queue lies.
       */
      public String getProject() {
        return project;
      }

      /** The project under which the queue lies. */
      public Delete setProject(String project) {
        this.project = project;
        return this;
      }

      /** The taskqueue to delete a task from. */
      @com.google.api.client.util.Key
      private String taskqueue;

      /** The taskqueue to delete a task from.
       */
      public String getTaskqueue() {
        return taskqueue;
      }

      /** The taskqueue to delete a task from. */
      public Delete setTaskqueue(String taskqueue) {
        this.taskqueue = taskqueue;
        return this;
      }

      /** The id of the task to delete. */
      @com.google.api.client.util.Key
      private String task;

      /** The id of the task to delete.
       */
      public String getTask() {
        return task;
      }

      /** The id of the task to delete. */
      public Delete setTask(String task) {
        this.task = task;
        return this;
      }

    }
    /**
     * Get a particular task from a TaskQueue.
     *
     * Create a request for the method "tasks.get".
     *
     * This request holds the parameters needed by the the taskqueue server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param project The project under which the queue lies.
     * @param taskqueue The taskqueue in which the task belongs.
     * @param task The task to get properties of.
     * @return the request
     */
    public Get get(String project, String taskqueue, String task) throws java.io.IOException {
      Get result = new Get(project, taskqueue, task);
      initialize(result);
      return result;
    }

    public class Get extends TaskqueueRequest<com.google.api.services.taskqueue.model.Task> {

      private static final String REST_PATH = "{project}/taskqueues/{taskqueue}/tasks/{task}";

      /**
       * Get a particular task from a TaskQueue.
       *
       * Create a request for the method "tasks.get".
       *
       * This request holds the parameters needed by the the taskqueue server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param project The project under which the queue lies.
       * @param taskqueue The taskqueue in which the task belongs.
       * @param task The task to get properties of.
       * @since 1.13
       */
      protected Get(String project, String taskqueue, String task) {
        super(Taskqueue.this, "GET", REST_PATH, null, com.google.api.services.taskqueue.model.Task.class);
        this.project = Preconditions.checkNotNull(project, "Required parameter project must be specified.");
        this.taskqueue = Preconditions.checkNotNull(taskqueue, "Required parameter taskqueue must be specified.");
        this.task = Preconditions.checkNotNull(task, "Required parameter task must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The project under which the queue lies. */
      @com.google.api.client.util.Key
      private String project;

      /** The project under which the queue lies.
       */
      public String getProject() {
        return project;
      }

      /** The project under which the queue lies. */
      public Get setProject(String project) {
        this.project = project;
        return this;
      }

      /** The taskqueue in which the task belongs. */
      @com.google.api.client.util.Key
      private String taskqueue;

      /** The taskqueue in which the task belongs.
       */
      public String getTaskqueue() {
        return taskqueue;
      }

      /** The taskqueue in which the task belongs. */
      public Get setTaskqueue(String taskqueue) {
        this.taskqueue = taskqueue;
        return this;
      }

      /** The task to get properties of. */
      @com.google.api.client.util.Key
      private String task;

      /** The task to get properties of.
       */
      public String getTask() {
        return task;
      }

      /** The task to get properties of. */
      public Get setTask(String task) {
        this.task = task;
        return this;
      }

    }
    /**
     * Insert a new task in a TaskQueue
     *
     * Create a request for the method "tasks.insert".
     *
     * This request holds the parameters needed by the the taskqueue server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param project The project under which the queue lies
     * @param taskqueue The taskqueue to insert the task into
     * @param content the {@link com.google.api.services.taskqueue.model.Task}
     * @return the request
     */
    public Insert insert(String project, String taskqueue, com.google.api.services.taskqueue.model.Task content) throws java.io.IOException {
      Insert result = new Insert(project, taskqueue, content);
      initialize(result);
      return result;
    }

    public class Insert extends TaskqueueRequest<com.google.api.services.taskqueue.model.Task> {

      private static final String REST_PATH = "{project}/taskqueues/{taskqueue}/tasks";

      /**
       * Insert a new task in a TaskQueue
       *
       * Create a request for the method "tasks.insert".
       *
       * This request holds the parameters needed by the the taskqueue server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param project The project under which the queue lies
       * @param taskqueue The taskqueue to insert the task into
       * @param content the {@link com.google.api.services.taskqueue.model.Task}
       * @since 1.13
       */
      protected Insert(String project, String taskqueue, com.google.api.services.taskqueue.model.Task content) {
        super(Taskqueue.this, "POST", REST_PATH, content, com.google.api.services.taskqueue.model.Task.class);
        this.project = Preconditions.checkNotNull(project, "Required parameter project must be specified.");
        this.taskqueue = Preconditions.checkNotNull(taskqueue, "Required parameter taskqueue must be specified.");
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /** The project under which the queue lies */
      @com.google.api.client.util.Key
      private String project;

      /** The project under which the queue lies
       */
      public String getProject() {
        return project;
      }

      /** The project under which the queue lies */
      public Insert setProject(String project) {
        this.project = project;
        return this;
      }

      /** The taskqueue to insert the task into */
      @com.google.api.client.util.Key
      private String taskqueue;

      /** The taskqueue to insert the task into
       */
      public String getTaskqueue() {
        return taskqueue;
      }

      /** The taskqueue to insert the task into */
      public Insert setTaskqueue(String taskqueue) {
        this.taskqueue = taskqueue;
        return this;
      }

    }
    /**
     * Lease 1 or more tasks from a TaskQueue.
     *
     * Create a request for the method "tasks.lease".
     *
     * This request holds the parameters needed by the the taskqueue server.  After setting any optional
     * parameters, call the {@link Lease#execute()} method to invoke the remote operation.
     *
     * @param project The project under which the queue lies.
     * @param taskqueue The taskqueue to lease a task from.
     * @param numTasks The number of tasks to lease.
     * @param leaseSecs The lease in seconds.
     * @return the request
     */
    public Lease lease(String project, String taskqueue, Integer numTasks, Integer leaseSecs) throws java.io.IOException {
      Lease result = new Lease(project, taskqueue, numTasks, leaseSecs);
      initialize(result);
      return result;
    }

    public class Lease extends TaskqueueRequest<com.google.api.services.taskqueue.model.Tasks> {

      private static final String REST_PATH = "{project}/taskqueues/{taskqueue}/tasks/lease";

      /**
       * Lease 1 or more tasks from a TaskQueue.
       *
       * Create a request for the method "tasks.lease".
       *
       * This request holds the parameters needed by the the taskqueue server.  After setting any
       * optional parameters, call the {@link Lease#execute()} method to invoke the remote operation.
       * <p> {@link Lease#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param project The project under which the queue lies.
       * @param taskqueue The taskqueue to lease a task from.
       * @param numTasks The number of tasks to lease.
       * @param leaseSecs The lease in seconds.
       * @since 1.13
       */
      protected Lease(String project, String taskqueue, Integer numTasks, Integer leaseSecs) {
        super(Taskqueue.this, "POST", REST_PATH, null, com.google.api.services.taskqueue.model.Tasks.class);
        this.project = Preconditions.checkNotNull(project, "Required parameter project must be specified.");
        this.taskqueue = Preconditions.checkNotNull(taskqueue, "Required parameter taskqueue must be specified.");
        this.numTasks = Preconditions.checkNotNull(numTasks, "Required parameter numTasks must be specified.");
        this.leaseSecs = Preconditions.checkNotNull(leaseSecs, "Required parameter leaseSecs must be specified.");
      }

      @Override
      public Lease setAlt(String alt) {
        return (Lease) super.setAlt(alt);
      }

      @Override
      public Lease setFields(String fields) {
        return (Lease) super.setFields(fields);
      }

      @Override
      public Lease setKey(String key) {
        return (Lease) super.setKey(key);
      }

      @Override
      public Lease setOauthToken(String oauthToken) {
        return (Lease) super.setOauthToken(oauthToken);
      }

      @Override
      public Lease setPrettyPrint(Boolean prettyPrint) {
        return (Lease) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Lease setQuotaUser(String quotaUser) {
        return (Lease) super.setQuotaUser(quotaUser);
      }

      @Override
      public Lease setUserIp(String userIp) {
        return (Lease) super.setUserIp(userIp);
      }

      /** The project under which the queue lies. */
      @com.google.api.client.util.Key
      private String project;

      /** The project under which the queue lies.
       */
      public String getProject() {
        return project;
      }

      /** The project under which the queue lies. */
      public Lease setProject(String project) {
        this.project = project;
        return this;
      }

      /** The taskqueue to lease a task from. */
      @com.google.api.client.util.Key
      private String taskqueue;

      /** The taskqueue to lease a task from.
       */
      public String getTaskqueue() {
        return taskqueue;
      }

      /** The taskqueue to lease a task from. */
      public Lease setTaskqueue(String taskqueue) {
        this.taskqueue = taskqueue;
        return this;
      }

      /** The number of tasks to lease. */
      @com.google.api.client.util.Key
      private Integer numTasks;

      /** The number of tasks to lease.
       */
      public Integer getNumTasks() {
        return numTasks;
      }

      /** The number of tasks to lease. */
      public Lease setNumTasks(Integer numTasks) {
        this.numTasks = numTasks;
        return this;
      }

      /** The lease in seconds. */
      @com.google.api.client.util.Key
      private Integer leaseSecs;

      /** The lease in seconds.
       */
      public Integer getLeaseSecs() {
        return leaseSecs;
      }

      /** The lease in seconds. */
      public Lease setLeaseSecs(Integer leaseSecs) {
        this.leaseSecs = leaseSecs;
        return this;
      }

      /** When true, all returned tasks will have the same tag */
      @com.google.api.client.util.Key
      private Boolean groupByTag;

      /** When true, all returned tasks will have the same tag
       */
      public Boolean getGroupByTag() {
        return groupByTag;
      }

      /** When true, all returned tasks will have the same tag */
      public Lease setGroupByTag(Boolean groupByTag) {
        this.groupByTag = groupByTag;
        return this;
      }

      /**
     * The tag allowed for tasks in the response. Must only be specified if group_by_tag is true. If
     * group_by_tag is true and tag is not specified the tag will be that of the oldest task by eta,
     * i.e. the first available tag
     */
      @com.google.api.client.util.Key
      private String tag;

      /** The tag allowed for tasks in the response. Must only be specified if group_by_tag is true. If
     group_by_tag is true and tag is not specified the tag will be that of the oldest task by eta, i.e.
     the first available tag
       */
      public String getTag() {
        return tag;
      }

      /**
     * The tag allowed for tasks in the response. Must only be specified if group_by_tag is true. If
     * group_by_tag is true and tag is not specified the tag will be that of the oldest task by eta,
     * i.e. the first available tag
     */
      public Lease setTag(String tag) {
        this.tag = tag;
        return this;
      }

    }
    /**
     * List Tasks in a TaskQueue
     *
     * Create a request for the method "tasks.list".
     *
     * This request holds the parameters needed by the the taskqueue server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param project The project under which the queue lies.
     * @param taskqueue The id of the taskqueue to list tasks from.
     * @return the request
     */
    public List list(String project, String taskqueue) throws java.io.IOException {
      List result = new List(project, taskqueue);
      initialize(result);
      return result;
    }

    public class List extends TaskqueueRequest<com.google.api.services.taskqueue.model.Tasks2> {

      private static final String REST_PATH = "{project}/taskqueues/{taskqueue}/tasks";

      /**
       * List Tasks in a TaskQueue
       *
       * Create a request for the method "tasks.list".
       *
       * This request holds the parameters needed by the the taskqueue server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param project The project under which the queue lies.
       * @param taskqueue The id of the taskqueue to list tasks from.
       * @since 1.13
       */
      protected List(String project, String taskqueue) {
        super(Taskqueue.this, "GET", REST_PATH, null, com.google.api.services.taskqueue.model.Tasks2.class);
        this.project = Preconditions.checkNotNull(project, "Required parameter project must be specified.");
        this.taskqueue = Preconditions.checkNotNull(taskqueue, "Required parameter taskqueue must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** The project under which the queue lies. */
      @com.google.api.client.util.Key
      private String project;

      /** The project under which the queue lies.
       */
      public String getProject() {
        return project;
      }

      /** The project under which the queue lies. */
      public List setProject(String project) {
        this.project = project;
        return this;
      }

      /** The id of the taskqueue to list tasks from. */
      @com.google.api.client.util.Key
      private String taskqueue;

      /** The id of the taskqueue to list tasks from.
       */
      public String getTaskqueue() {
        return taskqueue;
      }

      /** The id of the taskqueue to list tasks from. */
      public List setTaskqueue(String taskqueue) {
        this.taskqueue = taskqueue;
        return this;
      }

    }
    /**
     * Update tasks that are leased out of a TaskQueue. This method supports patch semantics.
     *
     * Create a request for the method "tasks.patch".
     *
     * This request holds the parameters needed by the the taskqueue server.  After setting any optional
     * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param project The project under which the queue lies.
     * @param taskqueue
     * @param task
     * @param newLeaseSeconds The new lease in seconds.
     * @param content the {@link com.google.api.services.taskqueue.model.Task}
     * @return the request
     */
    public Patch patch(String project, String taskqueue, String task, Integer newLeaseSeconds, com.google.api.services.taskqueue.model.Task content) throws java.io.IOException {
      Patch result = new Patch(project, taskqueue, task, newLeaseSeconds, content);
      initialize(result);
      return result;
    }

    public class Patch extends TaskqueueRequest<com.google.api.services.taskqueue.model.Task> {

      private static final String REST_PATH = "{project}/taskqueues/{taskqueue}/tasks/{task}";

      /**
       * Update tasks that are leased out of a TaskQueue. This method supports patch semantics.
       *
       * Create a request for the method "tasks.patch".
       *
       * This request holds the parameters needed by the the taskqueue server.  After setting any
       * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       * <p> {@link Patch#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param project The project under which the queue lies.
       * @param taskqueue
       * @param task
       * @param newLeaseSeconds The new lease in seconds.
       * @param content the {@link com.google.api.services.taskqueue.model.Task}
       * @since 1.13
       */
      protected Patch(String project, String taskqueue, String task, Integer newLeaseSeconds, com.google.api.services.taskqueue.model.Task content) {
        super(Taskqueue.this, "PATCH", REST_PATH, content, com.google.api.services.taskqueue.model.Task.class);
        this.project = Preconditions.checkNotNull(project, "Required parameter project must be specified.");
        this.taskqueue = Preconditions.checkNotNull(taskqueue, "Required parameter taskqueue must be specified.");
        this.task = Preconditions.checkNotNull(task, "Required parameter task must be specified.");
        this.newLeaseSeconds = Preconditions.checkNotNull(newLeaseSeconds, "Required parameter newLeaseSeconds must be specified.");
      }

      @Override
      public Patch setAlt(String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(String fields) {
        return (Patch) super.setFields(fields);
      }

      @Override
      public Patch setKey(String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setOauthToken(String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setPrettyPrint(Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setQuotaUser(String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setUserIp(String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      /** The project under which the queue lies. */
      @com.google.api.client.util.Key
      private String project;

      /** The project under which the queue lies.
       */
      public String getProject() {
        return project;
      }

      /** The project under which the queue lies. */
      public Patch setProject(String project) {
        this.project = project;
        return this;
      }

      @com.google.api.client.util.Key
      private String taskqueue;

      /**

       */
      public String getTaskqueue() {
        return taskqueue;
      }

      public Patch setTaskqueue(String taskqueue) {
        this.taskqueue = taskqueue;
        return this;
      }

      @com.google.api.client.util.Key
      private String task;

      /**

       */
      public String getTask() {
        return task;
      }

      public Patch setTask(String task) {
        this.task = task;
        return this;
      }

      /** The new lease in seconds. */
      @com.google.api.client.util.Key
      private Integer newLeaseSeconds;

      /** The new lease in seconds.
       */
      public Integer getNewLeaseSeconds() {
        return newLeaseSeconds;
      }

      /** The new lease in seconds. */
      public Patch setNewLeaseSeconds(Integer newLeaseSeconds) {
        this.newLeaseSeconds = newLeaseSeconds;
        return this;
      }

    }
    /**
     * Update tasks that are leased out of a TaskQueue.
     *
     * Create a request for the method "tasks.update".
     *
     * This request holds the parameters needed by the the taskqueue server.  After setting any optional
     * parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param project The project under which the queue lies.
     * @param taskqueue
     * @param task
     * @param newLeaseSeconds The new lease in seconds.
     * @param content the {@link com.google.api.services.taskqueue.model.Task}
     * @return the request
     */
    public Update update(String project, String taskqueue, String task, Integer newLeaseSeconds, com.google.api.services.taskqueue.model.Task content) throws java.io.IOException {
      Update result = new Update(project, taskqueue, task, newLeaseSeconds, content);
      initialize(result);
      return result;
    }

    public class Update extends TaskqueueRequest<com.google.api.services.taskqueue.model.Task> {

      private static final String REST_PATH = "{project}/taskqueues/{taskqueue}/tasks/{task}";

      /**
       * Update tasks that are leased out of a TaskQueue.
       *
       * Create a request for the method "tasks.update".
       *
       * This request holds the parameters needed by the the taskqueue server.  After setting any
       * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
       * <p> {@link Update#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param project The project under which the queue lies.
       * @param taskqueue
       * @param task
       * @param newLeaseSeconds The new lease in seconds.
       * @param content the {@link com.google.api.services.taskqueue.model.Task}
       * @since 1.13
       */
      protected Update(String project, String taskqueue, String task, Integer newLeaseSeconds, com.google.api.services.taskqueue.model.Task content) {
        super(Taskqueue.this, "POST", REST_PATH, content, com.google.api.services.taskqueue.model.Task.class);
        this.project = Preconditions.checkNotNull(project, "Required parameter project must be specified.");
        this.taskqueue = Preconditions.checkNotNull(taskqueue, "Required parameter taskqueue must be specified.");
        this.task = Preconditions.checkNotNull(task, "Required parameter task must be specified.");
        this.newLeaseSeconds = Preconditions.checkNotNull(newLeaseSeconds, "Required parameter newLeaseSeconds must be specified.");
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      /** The project under which the queue lies. */
      @com.google.api.client.util.Key
      private String project;

      /** The project under which the queue lies.
       */
      public String getProject() {
        return project;
      }

      /** The project under which the queue lies. */
      public Update setProject(String project) {
        this.project = project;
        return this;
      }

      @com.google.api.client.util.Key
      private String taskqueue;

      /**

       */
      public String getTaskqueue() {
        return taskqueue;
      }

      public Update setTaskqueue(String taskqueue) {
        this.taskqueue = taskqueue;
        return this;
      }

      @com.google.api.client.util.Key
      private String task;

      /**

       */
      public String getTask() {
        return task;
      }

      public Update setTask(String task) {
        this.task = task;
        return this;
      }

      /** The new lease in seconds. */
      @com.google.api.client.util.Key
      private Integer newLeaseSeconds;

      /** The new lease in seconds.
       */
      public Integer getNewLeaseSeconds() {
        return newLeaseSeconds;
      }

      /** The new lease in seconds. */
      public Update setNewLeaseSeconds(Integer newLeaseSeconds) {
        this.newLeaseSeconds = newLeaseSeconds;
        return this;
      }

    }

  }

  /**
   * Builder for {@link Taskqueue}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Taskqueue}. */
    @Override
    public Taskqueue build() {
      return new Taskqueue(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link TaskqueueRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setTaskqueueRequestInitializer(
        TaskqueueRequestInitializer taskqueueRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(taskqueueRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
