/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.taskqueue.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Model definition for Task.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the TaskQueue API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Task extends GenericJson {

  /**
   * Time (in seconds since the epoch) at which the task was enqueued.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long enqueueTimestamp;

  /**
   * Name of the task.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind of object returned, in this case set to task.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Time (in seconds since the epoch) at which the task lease will expire. This value is 0 if the
   * task isnt currently leased out to a worker.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long leaseTimestamp;

  /**
   * A bag of bytes which is the task payload. The payload on the JSON side is always Base64
   * encoded.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String payloadBase64;

  /**
   * Name of the queue that the task is in.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String queueName;

  /**
   * The number of leases applied to this task.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("retry_count")
  private Integer retryCount;

  /**
   * Tag for the task, could be used later to lease tasks grouped by a specific tag.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String tag;

  /**
   * Time (in seconds since the epoch) at which the task was enqueued.
   * The value returned may be {@code null}.
   */
  public Long getEnqueueTimestamp() {
    return enqueueTimestamp;
  }

  /**
   * Time (in seconds since the epoch) at which the task was enqueued.
   * The value set may be {@code null}.
   */
  public Task setEnqueueTimestamp(Long enqueueTimestamp) {
    this.enqueueTimestamp = enqueueTimestamp;
    return this;
  }

  /**
   * Name of the task.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Name of the task.
   * The value set may be {@code null}.
   */
  public Task setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of object returned, in this case set to task.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of object returned, in this case set to task.
   * The value set may be {@code null}.
   */
  public Task setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Time (in seconds since the epoch) at which the task lease will expire. This value is 0 if the
   * task isnt currently leased out to a worker.
   * The value returned may be {@code null}.
   */
  public Long getLeaseTimestamp() {
    return leaseTimestamp;
  }

  /**
   * Time (in seconds since the epoch) at which the task lease will expire. This value is 0 if the
   * task isnt currently leased out to a worker.
   * The value set may be {@code null}.
   */
  public Task setLeaseTimestamp(Long leaseTimestamp) {
    this.leaseTimestamp = leaseTimestamp;
    return this;
  }

  /**
   * A bag of bytes which is the task payload. The payload on the JSON side is always Base64
   * encoded.
   * The value returned may be {@code null}.
   */
  public String getPayloadBase64() {
    return payloadBase64;
  }

  /**
   * A bag of bytes which is the task payload. The payload on the JSON side is always Base64
   * encoded.
   * The value set may be {@code null}.
   */
  public Task setPayloadBase64(String payloadBase64) {
    this.payloadBase64 = payloadBase64;
    return this;
  }

  /**
   * Name of the queue that the task is in.
   * The value returned may be {@code null}.
   */
  public String getQueueName() {
    return queueName;
  }

  /**
   * Name of the queue that the task is in.
   * The value set may be {@code null}.
   */
  public Task setQueueName(String queueName) {
    this.queueName = queueName;
    return this;
  }

  /**
   * The number of leases applied to this task.
   * The value returned may be {@code null}.
   */
  public Integer getRetryCount() {
    return retryCount;
  }

  /**
   * The number of leases applied to this task.
   * The value set may be {@code null}.
   */
  public Task setRetryCount(Integer retryCount) {
    this.retryCount = retryCount;
    return this;
  }

  /**
   * Tag for the task, could be used later to lease tasks grouped by a specific tag.
   * The value returned may be {@code null}.
   */
  public String getTag() {
    return tag;
  }

  /**
   * Tag for the task, could be used later to lease tasks grouped by a specific tag.
   * The value set may be {@code null}.
   */
  public Task setTag(String tag) {
    this.tag = tag;
    return this;
  }

}
