/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.taskqueue.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Model definition for TaskQueue.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the TaskQueue API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class TaskQueue extends GenericJson {

  /**
   * ACLs that are applicable to this TaskQueue object.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Acl acl;

  /**
   * Name of the taskqueue.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind of REST object returned, in this case taskqueue.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The number of times we should lease out tasks before giving up on them. If unset we lease them
   * out forever until a worker deletes the task.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer maxLeases;

  /**
   * Statistics for the TaskQueue object in question.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Stats stats;

  /**
   * ACLs that are applicable to this TaskQueue object.
   * The value returned may be {@code null}.
   */
  public Acl getAcl() {
    return acl;
  }

  /**
   * ACLs that are applicable to this TaskQueue object.
   * The value set may be {@code null}.
   */
  public TaskQueue setAcl(Acl acl) {
    this.acl = acl;
    return this;
  }

  /**
   * Name of the taskqueue.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Name of the taskqueue.
   * The value set may be {@code null}.
   */
  public TaskQueue setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of REST object returned, in this case taskqueue.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of REST object returned, in this case taskqueue.
   * The value set may be {@code null}.
   */
  public TaskQueue setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The number of times we should lease out tasks before giving up on them. If unset we lease them
   * out forever until a worker deletes the task.
   * The value returned may be {@code null}.
   */
  public Integer getMaxLeases() {
    return maxLeases;
  }

  /**
   * The number of times we should lease out tasks before giving up on them. If unset we lease them
   * out forever until a worker deletes the task.
   * The value set may be {@code null}.
   */
  public TaskQueue setMaxLeases(Integer maxLeases) {
    this.maxLeases = maxLeases;
    return this;
  }

  /**
   * Statistics for the TaskQueue object in question.
   * The value returned may be {@code null}.
   */
  public Stats getStats() {
    return stats;
  }

  /**
   * Statistics for the TaskQueue object in question.
   * The value set may be {@code null}.
   */
  public TaskQueue setStats(Stats stats) {
    this.stats = stats;
    return this;
  }

  /**
   * ACLs that are applicable to this TaskQueue object.
   */
  public static final class Acl extends GenericJson {

    /**
     * Email addresses of users who are "admins" of the TaskQueue. This means they can control the
     * queue, eg set ACLs for the queue.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<String> adminEmails;

    /**
     * Email addresses of users who can "consume" tasks from the TaskQueue. This means they can
     * Dequeue and Delete tasks from the queue.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<String> consumerEmails;

    /**
     * Email addresses of users who can "produce" tasks into the TaskQueue. This means they can Insert
     * tasks into the queue.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<String> producerEmails;

    /**
     * Email addresses of users who are "admins" of the TaskQueue. This means they can control the
     * queue, eg set ACLs for the queue.
     * The value returned may be {@code null}.
     */
    public java.util.List<String> getAdminEmails() {
      return adminEmails;
    }

    /**
     * Email addresses of users who are "admins" of the TaskQueue. This means they can control the
     * queue, eg set ACLs for the queue.
     * The value set may be {@code null}.
     */
    public Acl setAdminEmails(java.util.List<String> adminEmails) {
      this.adminEmails = adminEmails;
      return this;
    }

    /**
     * Email addresses of users who can "consume" tasks from the TaskQueue. This means they can
     * Dequeue and Delete tasks from the queue.
     * The value returned may be {@code null}.
     */
    public java.util.List<String> getConsumerEmails() {
      return consumerEmails;
    }

    /**
     * Email addresses of users who can "consume" tasks from the TaskQueue. This means they can
     * Dequeue and Delete tasks from the queue.
     * The value set may be {@code null}.
     */
    public Acl setConsumerEmails(java.util.List<String> consumerEmails) {
      this.consumerEmails = consumerEmails;
      return this;
    }

    /**
     * Email addresses of users who can "produce" tasks into the TaskQueue. This means they can Insert
     * tasks into the queue.
     * The value returned may be {@code null}.
     */
    public java.util.List<String> getProducerEmails() {
      return producerEmails;
    }

    /**
     * Email addresses of users who can "produce" tasks into the TaskQueue. This means they can Insert
     * tasks into the queue.
     * The value set may be {@code null}.
     */
    public Acl setProducerEmails(java.util.List<String> producerEmails) {
      this.producerEmails = producerEmails;
      return this;
    }

  }

  /**
   * Statistics for the TaskQueue object in question.
   */
  public static final class Stats extends GenericJson {

    /**
     * Number of tasks leased in the last hour.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long leasedLastHour;

    /**
     * Number of tasks leased in the last minute.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long leasedLastMinute;

    /**
     * The timestamp (in seconds since the epoch) of the oldest unfinished task.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long oldestTask;

    /**
     * Number of tasks in the queue.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer totalTasks;

    /**
     * Number of tasks leased in the last hour.
     * The value returned may be {@code null}.
     */
    public Long getLeasedLastHour() {
      return leasedLastHour;
    }

    /**
     * Number of tasks leased in the last hour.
     * The value set may be {@code null}.
     */
    public Stats setLeasedLastHour(Long leasedLastHour) {
      this.leasedLastHour = leasedLastHour;
      return this;
    }

    /**
     * Number of tasks leased in the last minute.
     * The value returned may be {@code null}.
     */
    public Long getLeasedLastMinute() {
      return leasedLastMinute;
    }

    /**
     * Number of tasks leased in the last minute.
     * The value set may be {@code null}.
     */
    public Stats setLeasedLastMinute(Long leasedLastMinute) {
      this.leasedLastMinute = leasedLastMinute;
      return this;
    }

    /**
     * The timestamp (in seconds since the epoch) of the oldest unfinished task.
     * The value returned may be {@code null}.
     */
    public Long getOldestTask() {
      return oldestTask;
    }

    /**
     * The timestamp (in seconds since the epoch) of the oldest unfinished task.
     * The value set may be {@code null}.
     */
    public Stats setOldestTask(Long oldestTask) {
      this.oldestTask = oldestTask;
      return this;
    }

    /**
     * Number of tasks in the queue.
     * The value returned may be {@code null}.
     */
    public Integer getTotalTasks() {
      return totalTasks;
    }

    /**
     * Number of tasks in the queue.
     * The value set may be {@code null}.
     */
    public Stats setTotalTasks(Integer totalTasks) {
      this.totalTasks = totalTasks;
      return this;
    }

  }
}
